@@ -358,13 +358,18 @@ class Puppet::Resource::Catalog < Puppet::Graph::SimpleGraph
     result = @resource_table[title_key]
     if result.nil?
       # an instance has to be created in order to construct the unique key used when
-      # searching for aliases.
-      unless @aliases.empty? && !Puppet[:app_management]
+      # searching for aliases, or when app_management is active and nothing is found in
+      # which case it is needed by the CapabilityFinder.
+      res = nil
+      app_mgnt = Puppet[:app_management]
+      if app_mgnt || !@aliases.empty?
         res = Puppet::Resource.new(type, title, { :environment => @environment_instance })
-        result = @resource_table[[type_name, res.uniqueness_key].flatten]
+
+        # No need to build the uniqueness key unless there are aliases
+        result = @resource_table[[type_name, res.uniqueness_key].flatten] unless @aliases.empty?
       end
 
-      if result.nil? && Puppet[:app_management]
+      if result.nil? && app_mgnt
         resource_type = res.resource_type
         if resource_type && resource_type.is_capability?
           # @todo lutter 2015-03-10: this assumes that it is legal to just
@@ -419,8 +424,13 @@ class Puppet::Resource::Catalog < Puppet::Graph::SimpleGraph
     end
 
     if resources = data['resources']
+      # TODO: The deserializer needs a loader in order to deserialize types defined using the puppet language.
+      json_deserializer = nil
+      if Puppet[:rich_data] || result.environment_instance && result.environment_instance.rich_data?
+        json_deserializer = Puppet::Pops::Serialization::Deserializer.new(Puppet::Pops::Serialization::JSON::Reader.new([]), nil)
+      end
       result.add_resource(*resources.collect do |res|
-        Puppet::Resource.from_data_hash(res)
+        Puppet::Resource.from_data_hash(res, json_deserializer)
       end)
     end
 
@@ -472,6 +482,15 @@ class Puppet::Resource::Catalog < Puppet::Graph::SimpleGraph
       h
     end
 
+    resources = if @resources.empty?
+        []
+      elsif environment_instance.rich_data?
+        json_serializer = Puppet::Pops::Serialization::Serializer.new(Puppet::Pops::Serialization::JSON::Writer.new(''))
+        @resources.collect { |v| @resource_table[v].to_data_hash(json_serializer) }
+      else
+        @resources.collect { |v| @resource_table[v].to_data_hash }
+      end
+
     {
       'tags'      => tags,
       'name'      => name,
@@ -480,7 +499,7 @@ class Puppet::Resource::Catalog < Puppet::Graph::SimpleGraph
       'catalog_uuid' => catalog_uuid,
       'catalog_format' => catalog_format,
       'environment'  => environment.to_s,
-      'resources' => @resources.collect { |v| @resource_table[v].to_data_hash },
+      'resources' => resources,
       'edges'     => edges.   collect { |e| e.to_data_hash },
       'classes'   => classes,
     }.merge(metadata_hash.empty? ? {} : {'metadata' => metadata_hash})
